@@ -14,7 +14,7 @@ use Scalar::Util;
 
 with 'Data::Object::Role::Array';
 
-our $VERSION = '0.60'; # VERSION
+our $VERSION = '0.61'; # VERSION
 
 method new ($class: @args) {
 
@@ -67,7 +67,7 @@ Data::Object::Array - Array Object for Perl 5
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -84,40 +84,6 @@ to returning a new array reference. Unless stated, it may be safe to assume that
 the following methods copy, modify and return new array references based on
 their function.
 
-=head1 COMPOSITION
-
-This package inherits all functionality from the L<Data::Object::Role::Array>
-role and implements proxy methods as documented herewith.
-
-=head1 CODIFICATION
-
-Certain methods provided by the this module support codification, a process
-which converts a string argument into a code reference which can be used to
-supply a callback to the method called. A codified string can access its
-arguments by using variable names which correspond to letters in the alphabet
-which represent the position in the argument list. For example:
-
-  $array->example('$a + $b * $c', 100);
-
-  # if the example method does not supply any arguments automatically then
-  # the variable $a would be assigned the user-supplied value of 100,
-  # however, if the example method supplies two arguments automatically then
-  # those arugments would be assigned to the variables $a and $b whereas $c
-  # would be assigned the user-supplied value of 100
-
-  # e.g.
-
-  $array->each('the value at $index is $value');
-
-  # or
-
-  $array->each_n_values(4, 'the value at $index0 is $value0');
-
-  # etc
-
-Any place a codified string is accepted, a coderef or L<Data::Object::Code>
-object is also valid. Arguments are passed through the usual C<@_> list.
-
 =head1 METHODS
 
 =head2 all
@@ -850,6 +816,40 @@ The values method returns an array reference consisting of the elements in the
 array. This method essentially copies the content of the array into a new
 container. This method returns a L<Data::Object::Array> object.
 
+=head1 COMPOSITION
+
+This package inherits all functionality from the L<Data::Object::Role::Array>
+role and implements proxy methods as documented herewith.
+
+=head1 CODIFICATION
+
+Certain methods provided by the this module support codification, a process
+which converts a string argument into a code reference which can be used to
+supply a callback to the method called. A codified string can access its
+arguments by using variable names which correspond to letters in the alphabet
+which represent the position in the argument list. For example:
+
+  $array->example('$a + $b * $c', 100);
+
+  # if the example method does not supply any arguments automatically then
+  # the variable $a would be assigned the user-supplied value of 100,
+  # however, if the example method supplies two arguments automatically then
+  # those arugments would be assigned to the variables $a and $b whereas $c
+  # would be assigned the user-supplied value of 100
+
+  # e.g.
+
+  $array->each('the value at $index is $value');
+
+  # or
+
+  $array->each_n_values(4, 'the value at $index0 is $value0');
+
+  # etc
+
+Any place a codified string is accepted, a coderef or L<Data::Object::Code>
+object is also valid. Arguments are passed through the usual C<@_> list.
+
 =head1 ROLES
 
 This package is comprised of the following roles.
@@ -986,7 +986,7 @@ L<Data::Object::Signatures>
 
 =head1 AUTHOR
 
-Al Newkirk <anewkirk@ana.io>
+Al Newkirk <al@iamalnewkirk.com>
 
 =head1 COPYRIGHT AND LICENSE
 
