@@ -12,11 +12,15 @@ use Scalar::Util;
 
 use parent 'Exporter';
 
-our $VERSION = '0.60'; # VERSION
+our $VERSION = '0.61'; # VERSION
 
 our @EXPORT = @Data::Object::Syntax::EXPORT;
 
-*import = *Data::Object::Syntax::import;
+{
+  no warnings 'once';
+
+  *import = *Data::Object::Syntax::import;
+}
 
 1;
 
@@ -32,7 +36,7 @@ Data::Object::Class::Syntax - Class Declaration DSL for Perl 5
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -434,7 +438,7 @@ L<Data::Object::Signatures>
 
 =head1 AUTHOR
 
-Al Newkirk <anewkirk@ana.io>
+Al Newkirk <al@iamalnewkirk.com>
 
 =head1 COPYRIGHT AND LICENSE
 
