@@ -16,7 +16,7 @@ use Data::Dumper ();
 
 use overload ('""' => 'data', '~~' => 'data', fallback => 1,);
 
-our $VERSION = '0.60'; # VERSION
+our $VERSION = '0.61'; # VERSION
 
 has file       => (is => 'ro');
 has line       => (is => 'ro');
@@ -95,7 +95,7 @@ Data::Object::Exception - Exception Object for Perl 5
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -229,7 +229,7 @@ L<Data::Object::Signatures>
 
 =head1 AUTHOR
 
-Al Newkirk <anewkirk@ana.io>
+Al Newkirk <al@iamalnewkirk.com>
 
 =head1 COPYRIGHT AND LICENSE
 
