@@ -14,7 +14,7 @@ use Scalar::Util;
 
 with 'Data::Object::Role::Float';
 
-our $VERSION = '0.60'; # VERSION
+our $VERSION = '0.61'; # VERSION
 
 method new ($class: @args) {
 
@@ -61,7 +61,7 @@ Data::Object::Float - Float Object for Perl 5
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -80,11 +80,6 @@ opposed to returning a new float. Unless stated, it may be safe to assume that
 the following methods copy, modify and return new floats based on their
 function.
 
-=head1 COMPOSITION
-
-This package inherits all functionality from the L<Data::Object::Role::Float>
-role and implements proxy methods as documented herewith.
-
 =head1 METHODS
 
 =head2 data
@@ -276,6 +271,11 @@ The upto method returns an array reference containing integer increasing
 values up to and including the limit. This method returns a
 L<Data::Object::Array> object.
 
+=head1 COMPOSITION
+
+This package inherits all functionality from the L<Data::Object::Role::Float>
+role and implements proxy methods as documented herewith.
+
 =head1 ROLES
 
 This package is comprised of the following roles.
@@ -412,7 +412,7 @@ L<Data::Object::Signatures>
 
 =head1 AUTHOR
 
-Al Newkirk <anewkirk@ana.io>
+Al Newkirk <al@iamalnewkirk.com>
 
 =head1 COPYRIGHT AND LICENSE
 
