@@ -15,7 +15,7 @@ use Scalar::Util;
 
 with 'Data::Object::Role::Regexp';
 
-our $VERSION = '0.60'; # VERSION
+our $VERSION = '0.61'; # VERSION
 
 method new ($class: @args) {
 
@@ -68,7 +68,7 @@ Data::Object::Regexp - Regexp Object for Perl 5
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -82,11 +82,6 @@ Data::Object::Regexp provides routines for operating on Perl 5 regular
 expressions. Data::Object::Regexp methods work on data that meets the criteria
 for being a regular expression.
 
-=head1 COMPOSITION
-
-This package inherits all functionality from the L<Data::Object::Role::Regexp>
-role and implements proxy methods as documented herewith.
-
 =head1 METHODS
 
 =head2 data
@@ -272,6 +267,11 @@ If captured this method returns a L<Data::Object::Exception> object.
 The type method returns a string representing the internal data type object name.
 This method returns a L<Data::Object::String> object.
 
+=head1 COMPOSITION
+
+This package inherits all functionality from the L<Data::Object::Role::Regexp>
+role and implements proxy methods as documented herewith.
+
 =head1 ROLES
 
 This package is comprised of the following roles.
@@ -408,7 +408,7 @@ L<Data::Object::Signatures>
 
 =head1 AUTHOR
 
-Al Newkirk <anewkirk@ana.io>
+Al Newkirk <al@iamalnewkirk.com>
 
 =head1 COPYRIGHT AND LICENSE
 
