@@ -14,7 +14,7 @@ use Scalar::Util;
 
 extends 'Data::Object::Array';
 
-our $VERSION = '0.60'; # VERSION
+our $VERSION = '0.61'; # VERSION
 
 method captures () {
 
@@ -134,7 +134,7 @@ Data::Object::Regexp::Result - Regexp Result Object for Perl 5
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -368,7 +368,7 @@ L<Data::Object::Signatures>
 
 =head1 AUTHOR
 
-Al Newkirk <anewkirk@ana.io>
+Al Newkirk <al@iamalnewkirk.com>
 
 =head1 COPYRIGHT AND LICENSE
 
