@@ -12,12 +12,14 @@ use Data::Object::Library;
 use Data::Object::Signatures;
 use Scalar::Util;
 
-our $VERSION = '0.60'; # VERSION
+our $VERSION = '0.61'; # VERSION
 
 method dump () {
 
   require Data::Dumper;
 
+  no warnings 'once';
+
   local $Data::Dumper::Indent    = 0;
   local $Data::Dumper::Purity    = 0;
   local $Data::Dumper::Quotekeys = 0;
@@ -50,7 +52,7 @@ Data::Object::Role::Dumper - Dumper Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -162,7 +164,7 @@ L<Data::Object::Signatures>
 
 =head1 AUTHOR
 
-Al Newkirk <anewkirk@ana.io>
+Al Newkirk <al@iamalnewkirk.com>
 
 =head1 COPYRIGHT AND LICENSE
 
