@@ -13,7 +13,7 @@ use Data::Object::Signatures;
 
 use Carp ();
 
-our $VERSION = '0.60'; # VERSION
+our $VERSION = '0.61'; # VERSION
 
 method AUTOLOAD () {
 
@@ -56,7 +56,7 @@ Data::Object::Role::Proxyable - Proxyable Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -167,7 +167,7 @@ L<Data::Object::Signatures>
 
 =head1 AUTHOR
 
-Al Newkirk <anewkirk@ana.io>
+Al Newkirk <al@iamalnewkirk.com>
 
 =head1 COPYRIGHT AND LICENSE
 
