@@ -12,7 +12,7 @@ use Data::Object::Library;
 use Data::Object::Signatures;
 use Scalar::Util;
 
-our $VERSION = '0.60'; # VERSION
+our $VERSION = '0.61'; # VERSION
 
 method throw (@args) {
 
@@ -39,7 +39,7 @@ Data::Object::Role::Throwable - Throwable Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -152,7 +152,7 @@ L<Data::Object::Signatures>
 
 =head1 AUTHOR
 
-Al Newkirk <anewkirk@ana.io>
+Al Newkirk <al@iamalnewkirk.com>
 
 =head1 COPYRIGHT AND LICENSE
 
