@@ -14,7 +14,7 @@ use parent 'Type::Tiny::Signatures';
 
 our @DEFAULTS = @Type::Tiny::Signatures::DEFAULTS = 'Data::Object::Library';
 
-our $VERSION = '0.60'; # VERSION
+our $VERSION = '0.61'; # VERSION
 
 1;
 
@@ -30,7 +30,7 @@ Data::Object::Signatures - Signatures Object for Perl 5
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -136,7 +136,7 @@ L<Data::Object::Signatures>
 
 =head1 AUTHOR
 
-Al Newkirk <anewkirk@ana.io>
+Al Newkirk <al@iamalnewkirk.com>
 
 =head1 COPYRIGHT AND LICENSE
 
