@@ -12,7 +12,7 @@ use Sub::Quote;
 
 use parent 'Exporter';
 
-our $VERSION = '0.60'; # VERSION
+our $VERSION = '0.61'; # VERSION
 
 our @EXPORT = qw(
   alt
@@ -253,7 +253,7 @@ Data::Object::Syntax - Object Syntax DSL for Perl 5
 
 =head1 VERSION
 
-version 0.60
+version 0.61
 
 =head1 SYNOPSIS
 
@@ -620,7 +620,7 @@ L<Data::Object::Signatures>
 
 =head1 AUTHOR
 
-Al Newkirk <anewkirk@ana.io>
+Al Newkirk <al@iamalnewkirk.com>
 
 =head1 COPYRIGHT AND LICENSE
 
